@@ -122,7 +122,6 @@ class InstrumentedSample(InstrumentedBase):
         """ Converts degrees C to a raw ADC value for the Texas HDC2010. """
         return int((degc + 40) * 4096 / 165)
 
-
     def rh_percent_to_raw(self, rhpc):
         """ Converts from relative humidity in percent to a raw ADC value for the Texas HDC2010. """
         return int((rhpc * 4096) / 100)
@@ -143,8 +142,32 @@ class InstrumentedSample(InstrumentedBase):
             rawrh = self.rh_percent_to_raw(counter)
             yield {'adc': rawrh, 'ref': counter}
 
+    def pushsamplelist(self, trhlist: list):
+        """
+
+        :param trhlist: a list of dictionaries each containing temperature and relative humidity keys.
+        :return: None
+        """
+        for smpldict in trhlist:
+            tempdegc = smpldict['temp']
+            rhpc = smpldict['rh']
+            tempraw = self.temp_degc_to_raw(tempdegc)
+            rhraw = self.rh_percent_to_raw(rhpc)
+            # rhraw is ignored (set to -1) inside enc_pushsample if the format is temperature only.
+            self.ffimodule.lib.enc_pushsample(tempraw, rhraw)
+
+    def updateendstop(self, minutes: int):
+        """ Update the endstop with minutes elapsed since the most recent sample.
+
+        :param minutes: Minutes elapsed since the most recent sample.
+        :return: None
+        """
+        self.ffimodule.lib.enc_setelapsed(minutes)
+
 
 class InstrumentedSampleT(InstrumentedSample):
+    FORMAT_HDC2021_TEMPONLY = 2
+
     def __init__(self,
                  serial='ABCDEFGH',
                  secretkey='AAAACCCC11112222',
@@ -155,14 +178,15 @@ class InstrumentedSampleT(InstrumentedSample):
                  resetcause=0,
                  usehmac=True,
                  httpsdisable=False,
-                 tagerror=False
+                 tagerror=False,
+                 format=FORMAT_HDC2021_TEMPONLY
                  ):
         super(InstrumentedSampleT, self).__init__(baseurl,
                                                   serial,
                                                   secretkey,
                                                   smplintervalmins,
                                                   batteryadc=batteryadc,
-                                                  format=2,
+                                                  format=format,
                                                   resetsalltime=resetsalltime,
                                                   usehmac=usehmac,
                                                   httpsdisable=httpsdisable)
@@ -179,6 +203,8 @@ class InstrumentedSampleT(InstrumentedSample):
 
 
 class InstrumentedSampleTRH(InstrumentedSample):
+    FORMAT_HDC2021_TRH = 1
+
     def __init__(self,
                  serial='ABCDEFGH',
                  secretkey='AAAACCCC11112222',
@@ -189,14 +215,15 @@ class InstrumentedSampleTRH(InstrumentedSample):
                  resetcause=0,
                  usehmac=True,
                  httpsdisable=False,
-                 tagerror=False
+                 tagerror=False,
+                 format=FORMAT_HDC2021_TRH
                  ):
         super(InstrumentedSampleTRH, self).__init__(baseurl,
                                                     serial,
                                                     secretkey,
                                                     smplintervalmins,
                                                     batteryadc=batteryadc,
-                                                    format=1,
+                                                    format=format,
                                                     resetsalltime=resetsalltime,
                                                     usehmac=usehmac,
                                                     httpsdisable=httpsdisable)
@@ -213,26 +240,5 @@ class InstrumentedSampleTRH(InstrumentedSample):
             self.ffimodule.lib.enc_pushsample(tempsmpl['adc'], rhsmpl['adc'])
         return inlist
 
-    def pushsamplelist(self, trhlist: list):
-        """
-
-        :param trhlist: a list of dictionaries each containing temperature and relative humidity keys.
-        :return: None
-        """
-        for smpldict in trhlist:
-            tempdegc = smpldict['temp']
-            rhpc = smpldict['rh']
-            tempraw = self.temp_degc_to_raw(tempdegc)
-            rhraw = self.rh_percent_to_raw(rhpc)
-            self.ffimodule.lib.enc_pushsample(tempraw, rhraw)
-
-    def updateendstop(self, minutes: int):
-        """ Update the endstop with minutes elapsed since the most recent sample.
-
-        :param minutes: Minutes elapsed since the most recent sample.
-        :return: None
-        """
-        self.ffimodule.lib.enc_setelapsed(minutes)
-
     def geturlqs(self):
         return self.eepromba.get_url_parsedqs()
